@@ -1,7 +1,7 @@
 package IPC::System::Options;
 
 our $DATE = '2015-06-18'; # DATE
-our $VERSION = '0.12'; # VERSION
+our $VERSION = '0.13'; # VERSION
 
 use 5.010001;
 use strict;
@@ -79,7 +79,7 @@ sub _system_or_backtick {
                 $res = system join(" ", @args);
             } elsif (defined $opts->{shell}) {
                 # forbid shell
-                $res = system {$_[0]} @args;
+                $res = system {$args[0]} @args;
             } else {
                 # might or might not use shell (if @args == 1)
                 $res = system @args;
@@ -200,7 +200,7 @@ IPC::System::Options - Perl's system() and backtick/qx replacement/wrapper, with
 
 =head1 VERSION
 
-This document describes version 0.12 of IPC::System::Options (from Perl distribution IPC-System-Options), released on 2015-06-18.
+This document describes version 0.13 of IPC::System::Options (from Perl distribution IPC-System-Options), released on 2015-06-18.
 
 =head1 SYNOPSIS
 
